@@ -14,9 +14,6 @@ class ModelCheckpoint(Callback):
     UNRECOGNIZED_MODE = (
         "Unrecognized mode {mode}. Options are: 'max', 'min', 'auto'"
     )
-    INVALID_MODE_INFERENCE_MESSAGE = (
-        "Could not infer mode from meter {meter}"
-    )
 
     def __init__(self, path, monitor, mode='auto'):
         """ Constructor
@@ -50,10 +47,6 @@ class ModelCheckpoint(Callback):
     def on_train_begin(self):
         if self._mode.lower() == 'auto':
             self._mode = get_default_mode(self.trainer.meters[self.monitor_name])
-            if self._mode == '':
-                raise Exception(self.INVALID_MODE_INFERENCE_MESSAGE
-                                    .format(meter=self.monitor_name))
-
         self.is_better = self.criterion(self._mode)
 
         if not os.path.exists(self.path):
@@ -85,6 +78,14 @@ class ModelCheckpoint(Callback):
 
         value = self.trainer.metrics[self.monitor_name]
         if self.last_value is None or self.is_better(value):
+            if self.last_value is None:
+                message = "Model saved to {path}"
+            else:
+                message = "Model saved to {path}: {monitor} improved from {last_value:.3f} to {current_value:.3f}"
+            self.trainer.logger.info(message.format(path=repr(self.path),
+                                                    monitor=self.monitor_name,
+                                                    last_value=self.last_value,
+                                                    current_value=value))
             self.last_value = value
             index_content = [{self.monitor_name: self.last_value,
                               'epoch': self.trainer.epochs_trained}]
@@ -97,3 +98,11 @@ class ModelCheckpoint(Callback):
 
             torch.save(self.trainer.model.state_dict(), model_file)
             self.outperform = True
+
+    def __repr__(self):
+        return "{cls}(path={path}, monitor={monitor}, mode={mode})".format(
+            cls=self.__class__.__name__,
+            mode=repr(self._mode),
+            monitor=repr(self.monitor_name),
+            path=repr(self.path)
+        )
